@@ -57,11 +57,11 @@
 #include <urlutil.h>
 
 typedef KDevGenericFactory<TrollProjectPart> TrollProjectFactory;
-static const KDevPluginInfo data("kdevtrollproject");
-K_EXPORT_COMPONENT_FACTORY( libkdevtrollproject, TrollProjectFactory( data ) )
+static const KDevPluginInfo pluginData("kdevtrollproject");
+K_EXPORT_COMPONENT_FACTORY( libkdevtrollproject, TrollProjectFactory( pluginData ) )
 
 TrollProjectPart::TrollProjectPart(TQObject *parent, const char *name, const TQStringList& args )
-    : KDevBuildTool(&data, parent, name ? name : "TrollProjectPart")
+    : KDevBuildTool(&pluginData, parent, name ? name : "TrollProjectPart")
 {
     setInstance(TrollProjectFactory::instance());
 
@@ -246,7 +246,7 @@ TQString TrollProjectPart::makeEnvironment()
     DomUtil::PairList::ConstIterator it;
     bool hasTQtDir = false;
     for (it = envvars.begin(); it != envvars.end(); ++it) {
-        if( (*it).first == "QTDIR" )
+        if( (*it).first == "TQTDIR" )
 	    hasTQtDir = true;
 
         environstr += (*it).first;
@@ -257,7 +257,7 @@ TQString TrollProjectPart::makeEnvironment()
 
     if( !hasTQtDir && !isTQt4Project() && !DomUtil::readEntry(*projectDom(), "/kdevcppsupport/qt/root", "").isEmpty() )
     {
-         environstr += TQString( "QTDIR=" ) + EnvVarTools::quote( DomUtil::readEntry(*projectDom(), "/kdevcppsupport/qt/root", "") ) + TQString( " PATH=$TQTDIR/bin:$PATH " );
+         environstr += TQString( "TQTDIR=" ) + EnvVarTools::quote( DomUtil::readEntry(*projectDom(), "/kdevcppsupport/qt/root", "") ) + TQString( " PATH=$TQTDIR/bin:$PATH " );
     }
 
     TDEConfigGroup grp( kapp->config(), "MakeOutputView" );
@@ -808,7 +808,7 @@ void TrollProjectPart::buildBinDirs( TQStringList & dirs ) const
         TQString m_defaultTQtDir = DomUtil::readEntry(*projectDom(), "/kdevcppsupport/qt/root", "");
         if( !m_defaultTQtDir.isEmpty() )
             dirs << (m_defaultTQtDir + TQString( TQChar( TQDir::separator() ) ) + "bin" );
-        dirs << ( ::getenv("QTDIR") + TQString( TQChar( TQDir::separator() ) ) + "bin" );
+        dirs << ( ::getenv("TQTDIR") + TQString( TQChar( TQDir::separator() ) ) + "bin" );
     }
     TQStringList paths = TQStringList::split(":",::getenv("PATH"));
     dirs += paths;
@@ -851,7 +851,7 @@ TQString TrollProjectPart::findTQtDir()
 {
     TQStringList qtdirs;
     if( !isTQt4Project() )
-        qtdirs.push_back( ::getenv("QTDIR") );
+        qtdirs.push_back( ::getenv("TQTDIR") );
     qtdirs.push_back( TQDir::rootDirPath()+"usr"+TQString( TQChar( TQDir::separator() ) )+"lib"+TQString( TQChar( TQDir::separator() ) )+"qt"+TQString("%1").arg( DomUtil::readEntry( *projectDom(), "/kdevcppsupport/qt/version", "3") ) );
     qtdirs.push_back( TQDir::rootDirPath()+"usr"+TQString( TQChar( TQDir::separator() ) )+"lib"+TQString( TQChar( TQDir::separator() ) )+"qt"+TQString( TQChar( TQDir::separator() ) )+TQString("%1").arg( DomUtil::readEntry( *projectDom(), "/kdevcppsupport/qt/version", "3") ) );
     qtdirs.push_back( TQDir::rootDirPath()+"usr"+TQString( TQChar( TQDir::separator() ) )+"share"+TQString( TQChar( TQDir::separator() ) )+"qt"+TQString("%1").arg( DomUtil::readEntry( *projectDom(), "/kdevcppsupport/qt/version", "3") ) );
