@@ -449,7 +449,7 @@ void CCConfigWidget::initTQtTab()
 		m_kdevexternal->setChecked( true );
 	}else
 	{
-		m_qtdesigner->setChecked( true );
+		m_tqtdesigner->setChecked( true );
 	}
 }
 
@@ -546,7 +546,7 @@ void CCConfigWidget::toggleTQtVersion( bool )
   if ( m_versionQt4->isChecked() )
   {
     m_qtStyleVersion4->setEnabled( true );
-    m_qtdesigner->setChecked( true );
+    m_tqtdesigner->setChecked( true );
     m_kdevembedded->setEnabled( false );
     m_kdevexternal->setEnabled( false );
     pluginPaths->setEnabled( true );
