@@ -40,7 +40,7 @@ SettingsDialog::SettingsDialog( TQWidget* parent, const char* name, WFlags fl )
 		: SettingsDialogBase( parent, name, fl )
 {
 	TQStringList qtdirs;
-	qtdirs.push_back( ::getenv( "QTDIR" ) + TQString("/include") );
+	qtdirs.push_back( ::getenv( "TQTDIR" ) + TQString("/include") );
 	qtdirs.push_back( "/usr/lib/qt3/include" );
 	qtdirs.push_back( "/usr/lib/qt/include" );
 	qtdirs.push_back( "/usr/share/qt3/include" );
